Komenda zip w systemie Windows służy do tworzenia archiwów w formacie ZIP, które umożliwiają kompresję plików oraz folderów. Dzięki temu można zaoszczędzić miejsce na dysku oraz ułatwić przesyłanie danych. Format ZIP jest powszechnie stosowany w celu archiwizacji i dystrybucji plików.
zip [opcje] archiwum.zip plik1 plik2 ...
| Parametr | Opis |
|---|---|
| -r | Rekurencyjnie dodaje wszystkie pliki i foldery w podanym katalogu do archiwum. |
| -e | Tworzy zaszyfrowane archiwum, wymagające hasła do otwarcia. |
| -u | Dodaje tylko nowe pliki do istniejącego archiwum. |
| -d | Rozpakowuje archiwum ZIP do wskazanego katalogu. |
| -v | Wyświetla szczegółowe informacje o procesie kompresji. |
zip -r archiwum.zip folder_z_plikami
Powyższa komenda tworzy archiwum o nazwie archiwum.zip, które zawiera wszystkie pliki i podfoldery z katalogu folder_z_plikami. Użycie opcji -r pozwala na rekurencyjne dodawanie plików.
zip -e archiwum_zaszyfrowane.zip plik.txt
Ta komenda tworzy zaszyfrowane archiwum archiwum_zaszyfrowane.zip, które zawiera plik plik.txt. Użytkownik będzie musiał podać hasło, aby uzyskać dostęp do zawartości archiwum.
zip -u archiwum.zip nowy_plik.txt
Komenda ta dodaje tylko nowy plik nowy_plik.txt do istniejącego archiwum archiwum.zip, jeśli plik ten nie był wcześniej archiwizowany.
unzip archiwum.zip -d folder_docelowy
W tym przykładzie komenda unzip rozpakowuje zawartość archiwum archiwum.zip do katalogu folder_docelowy.
Niezbędne ciasteczka umożliwiają prawidłowe funkcjonowanie strony internetowej, zapewniając podstawowe funkcje, takie jak nawigacja po stronie i dostęp do jej zabezpieczonych obszarów. Bez tych ciasteczek strona nie może działać prawidłowo.
Niezbędne ciasteczka umożliwiają prawidłowe funkcjonowanie strony internetowej, zapewniając podstawowe funkcje, takie jak nawigacja po stronie i dostęp do jej zabezpieczonych obszarów. Bez tych ciasteczek strona nie może działać prawidłowo.
Wyrażam zgodę na wykorzystywanie plików cookie Google Analytics w celu prowadzenia anonimowych statystyk, analizy sposobu korzystania ze strony oraz jej ulepszania, przy czym część danych może być także używana przez Google do personalizacji i pomiaru skuteczności reklam.
Wyrażam zgodę na wykorzystywanie przez Google plików cookie i podobnych technologii w celu wyświetlania reklam spersonalizowanych, pomiaru ich skuteczności oraz zapewnienia bezpieczeństwa strony poprzez odróżnianie użytkowników od botów.
Ciasteczka (cookies) to małe pliki tekstowe, które mogą być wykorzystywane przez strony internetowe, by usprawnić doświadczenie użytkownika. Zgodnie z przepisami prawa, możemy przechowywać na Twoim urządzeniu ciasteczka, które są ściśle niezbędne do funkcjonowania tej strony. W przypadku wszystkich innych typów ciasteczek potrzebujemy Twojej zgody. Oznacza to, że ciasteczka klasyfikowane jako niezbędne są przetwarzane na podstawie art. 6 ust. 1 lit. f RODO. Wszystkie pozostałe ciasteczka, czyli te z kategorii preferencji i marketingu, są przetwarzane na podstawie art. 6 ust. 1 lit. a RODO. Nasza strona korzysta z różnych rodzajów ciasteczek. Niektóre ciasteczka są umieszczane przez usługi stron trzecich, które pojawiają się na naszych stronach. W każdej chwili możesz zmienić lub wycofać swoją zgodę z Oświadczenia o ciasteczkach na naszej stronie internetowej. Dowiedz się więcej o tym, kim jesteśmy, jak możesz się z nami skontaktować i jak przetwarzamy dane osobowe, zapoznając się z naszą Polityką Prywatności.